
#ifndef GRANTLEE_CORE_EXPORT_H
#define GRANTLEE_CORE_EXPORT_H

#ifdef GRANTLEE_CORE_STATIC_DEFINE
#  define GRANTLEE_CORE_EXPORT
#  define GRANTLEE_CORE_NO_EXPORT
#else
#  ifndef GRANTLEE_CORE_EXPORT
#    ifdef grantlee_core_EXPORTS
        /* We are building this library */
#      define GRANTLEE_CORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define GRANTLEE_CORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef GRANTLEE_CORE_NO_EXPORT
#    define GRANTLEE_CORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef GRANTLEE_CORE_DEPRECATED
#  define GRANTLEE_CORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef GRANTLEE_CORE_DEPRECATED_EXPORT
#  define GRANTLEE_CORE_DEPRECATED_EXPORT GRANTLEE_CORE_EXPORT GRANTLEE_CORE_DEPRECATED
#endif

#ifndef GRANTLEE_CORE_DEPRECATED_NO_EXPORT
#  define GRANTLEE_CORE_DEPRECATED_NO_EXPORT GRANTLEE_CORE_NO_EXPORT GRANTLEE_CORE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef GRANTLEE_CORE_NO_DEPRECATED
#    define GRANTLEE_CORE_NO_DEPRECATED
#  endif
#endif

#endif

#define GRANTLEE_TESTS_EXPORT GRANTLEE_CORE_EXPORT
